@@ -12,8 +12,9 @@ os.environ['PATH'] = '/opt/kubectl:/opt/awscli:' + os.environ['PATH']
 outdir = os.environ.get('TEST_OUTDIR', '/tmp')
 kubeconfig = os.path.join(outdir, 'kubeconfig')
 
+
 def patch_handler(event, context):
-    logger.info(json.dumps(event))
+    logger.info(json.dumps(dict(event, ResponseURL='...')))
 
     request_type = event['RequestType']
     props = event['ResourceProperties']
@@ -29,6 +30,9 @@ def patch_handler(event, context):
         '--kubeconfig', kubeconfig
     ])
 
+    if os.path.isfile(kubeconfig):
+        os.chmod(kubeconfig, 0o600)
+
     resource_name = props['ResourceName']
     resource_namespace = props['ResourceNamespace']
     apply_patch_json = props['ApplyPatchJson']
@@ -36,9 +40,9 @@ def patch_handler(event, context):
     patch_type = props['PatchType']
 
     patch_json = None
-    if request_type == 'Create' or request_type == 'Update': 
+    if request_type == 'Create' or request_type == 'Update':
         patch_json = apply_patch_json
-    elif request_type == 'Delete': 
+    elif request_type == 'Delete':
         patch_json = restore_patch_json
     else:
         raise Exception("invalid request type %s" % request_type)
@@ -47,7 +51,8 @@ def patch_handler(event, context):
 
 
 def kubectl(args):
-    retry = 3
+    maxAttempts = 3
+    retry = maxAttempts
     while retry > 0:
         try:
             cmd = [ 'kubectl', '--kubeconfig', kubeconfig ] + args
@@ -55,10 +60,11 @@ def kubectl(args):
         except subprocess.CalledProcessError as exc:
             output = exc.output
             if b'i/o timeout' in output and retry > 0:
-                logger.info("kubectl timed out, retries left: %s" % retry)
                 retry = retry - 1
+                logger.info("kubectl timed out, retries left: %s" % retry)
             else:
                 raise Exception(output)
         else:
             logger.info(output)
             return
+    raise Exception(f'Operation failed after {maxAttempts} attempts: {output}')
\ No newline at end of file
